/**
 * 
 */
package org.vamsas.client;

import java.io.DataInput;
import java.io.DataOutput;

/**
 * Object for accessing Client and User specific data
 * in an IClientDocument instance. 
 *
 */
public interface IClientAppdata {
  /**
   * @return true if Client's non-user specific application data is non-zero length.
   */
  boolean hasClientAppdata();
  /**
   * @return true if User's Client Application data is non-zero length
   */
  boolean hasUserAppdata();
  /**
   * 
   * @return byte array containing the Client's non-user specific application data
   */
  byte[] getClientAppdata();
  /**
   * 
   * @return byte array containing the Client's user specific application data
   */
  byte[] getUserAppdata();
  /**
   * set the non-User-specific application data
   * @param data - the new non-user-specific data
   */
  void setClientAppdata(byte[] data);
  /**
   * set the User-specific application data
   * @param data - the new user-specific data
   */
  void setUserAppdata(byte[] data);
  /**
   * @return non-user specific data output stream 
   */
  DataOutput getClientOutputStream();
  /**
   * @return non-user specific data input stream 
   */
  DataInput getClientInputStream();
  /**
   * 
   * @return user specific data output stream
   */
  DataOutput getUserOutputStream();
  /**
   * 
   * @return user specific data input stream
   */
  DataInput getUserInputStream();
}
